=================
geoglows.analysis
=================

Analysis
~~~~~~~~
Functions which post process results from the streamflow data service into additional, useful products

.. automodule:: geoglows.analysis
    :members:
        compute_daily_average, compute_monthly_average, compute_return_periods, compute_anomaly
